@@ -11,7 +11,7 @@ use Readonly;
 
 Readonly::Array our @COVERS => qw(hardback paperback);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 has authors => (
 	default => [],
@@ -28,10 +28,6 @@ has authors_of_introduction => (
 	is => 'ro',
 );
 
-has ccnb => (
-	is => 'ro',
-);
-
 has compilers => (
 	default => [],
 	is => 'ro',
@@ -101,10 +97,6 @@ has number_of_pages => (
 	is => 'ro',
 );
 
-has oclc => (
-	is => 'ro',
-);
-
 has photographers => (
 	default => [],
 	is => 'ro',
@@ -257,7 +249,6 @@ MARC::Convert::Wikidata::Object - Bibliographic Wikidata object defined by MARC
  my $authors_ar = $obj->authors;
  my $authors_of_afterword_ar = $obj->authors_of_afterword;
  my $authors_of_introduction_ar = $obj->authors_of_introduction;
- my $ccnb = $obj->ccnb;
  my $compilers = $obj->compilers;
  my $cover = $obj->cover;
  my $directors_ar = $obj->directors;
@@ -274,7 +265,6 @@ MARC::Convert::Wikidata::Object - Bibliographic Wikidata object defined by MARC
  my $languages_ar = $obj->languages;
  my $narrators_ar = $obj->narrators;
  my $number_of_pages = $obj->number_of_pages;
- my $oclc = $obj->oclc;
  my $photographers_ar = $obj->photographers;
  my $publication_date = $obj->publication_date;
  my $publishers_ar = $obj->publishers;
@@ -317,12 +307,6 @@ Reference to array with MARC::Convert::Wikidata::Object::People instances.
 
 Default value is reference to blank array.
 
-=item * C<ccnb>
-
-ČČNB (Česká národní bibliografie) id.
-
-Default value is undef.
-
 =item * C<compilers>
 
 List of compilers.
@@ -425,12 +409,6 @@ Number of pages.
 
 Default value is undef.
 
-=item * C<oclc>
-
-OCLC control number.
-
-Default value is undef.
-
 =item * C<photographers>
 
 List of photographers.
@@ -510,16 +488,6 @@ Get reference to array with author of introduction objects.
 
 Returns reference to array of MARC::Convert::Wikidata::Object::People instances.
 
-=head2 C<ccnb>
-
-I<It is deprecated. It will be removed in future.>
-
- my $ccnb = $obj->ccnb;
-
-Get ČČNB (Česká národní bibliografie) ID.
-
-Returns string.
-
 =head2 C<compilers>
 
  my $compilers_ar = $obj->compilers;
@@ -644,16 +612,6 @@ Returns reference to array of MARC::Convert::Wikidata::Object::People instances.
 
 TODO
 
-=head2 C<oclc>
-
-I<It is deprecated. It will be removed in future.>
-
- my $oclc = $obj->oclc;
-
-Get OCLC control number.
-
-Returns string.
-
 =head2 C<photographers>
 
  my $photographers_ar = $obj->photographers;
@@ -880,6 +838,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
